# TimeperiodPolicyTemplate

A timeperiod policy for providing reoccuring access 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**timezone** | **str** | IANA timezone for this timeperiod  | 
**days** | **[str]** | A list of this time condition is valid for. permitted values:    Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday  | 
**labels** | [**[LabelName]**](LabelName.md) | Restrict the timestamp to accesses for resources or users with one of these labels.  | 
**template_type** | **str** | The descriminator for the PolicyTemplate. Set this to &#x60;timeperiod&#x60; | 
**start_time_of_day** | [**TimeOfDayCondition**](TimeOfDayCondition.md) |  | [optional] 
**end_time_of_day** | [**TimeOfDayCondition**](TimeOfDayCondition.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


